<?php # $Id: serendipity_lang_en.inc.php,v 1.148 2005/04/08 22:50:24 garvinhicking Exp $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation by Torbjörn Hedberg <torbjorn@sm.luth.se>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'sv_SV.UTF8, sv_SV.UTF-8, swedish, sv, sv_SV, sv_SE.UTF8, sv_SE.UTF-8, sv_SE');
@define('DATE_FORMAT_ENTRY', '%A, %B %e. %Y');
@define('DATE_FORMAT_SHORT', '%Y-%m-%d %H:%M');
@define('WYSIWYG_LANG', 'se-utf');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', '.');
@define('NUMBER_FORMAT_THOUSANDS', ',');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity Administration');
@define('HAVE_TO_BE_LOGGED_ON', 'Du måste vara inloggad för att se den här sidan');
@define('WRONG_USERNAME_OR_PASSWORD', 'Du verkar ha fel användarnamn eller lösenord');
@define('APPEARANCE', 'Utseende');
@define('MANAGE_STYLES', 'Hantera stilar');
@define('CONFIGURE_PLUGINS', 'Konfigurera insticksmoduler');
@define('CONFIGURATION', 'Konfigurering');
@define('BACK_TO_BLOG', 'Tillbaka till bloggen');
@define('LOGIN', 'Logga in');
@define('LOGOUT', 'Logga ut');
@define('LOGGEDOUT', 'Utloggad.');
@define('CREATE', 'Skapa');
@define('SAVE', 'Spara');
@define('NAME', 'Namn');
@define('CREATE_NEW_CAT', 'Skapa ny kategori');
@define('I_WANT_THUMB', 'Jag vill använda miniatyren i min artikel.');
@define('I_WANT_BIG_IMAGE', 'Jag vill använda den större bilden i min artikel.');
@define('I_WANT_NO_LINK', 'Jag vill visa den som en bild');
@define('I_WANT_IT_TO_LINK', 'Jag vill visa den som en länk till denna url:');
@define('BACK', 'Tillbaka');
@define('FORWARD', 'Framåt');
@define('ANONYMOUS', 'Anonymt');
@define('NEW_TRACKBACK_TO', 'Ny trackback skapad till');
@define('NEW_COMMENT_TO', 'Ny kommentar skapad till');
@define('RECENT', 'Senaste...');
@define('OLDER', 'Äldre...');
@define('DONE', 'Klar');
@define('WELCOME_BACK', 'Välkommen tillbaka,');
@define('TITLE', 'Titel');
@define('DESCRIPTION', 'Beskrivning');
@define('PLACEMENT', 'Placering');
@define('DELETE', 'Ta bort');
@define('SAVE', 'Spara');
@define('UP', 'UPP');
@define('DOWN', 'NER');
@define('ENTRIES', 'Artiklar');
@define('NEW_ENTRY', 'Ny artikel');
@define('EDIT_ENTRIES', 'Redigera artiklar');
@define('CATEGORIES', 'Kategorier');
@define('WARNING_THIS_BLAHBLAH', "VARNING:\\nDetta kan ta lång tid om det är många bilder utan miniatyrer.");
@define('CREATE_THUMBS', 'Bygg om miniatyrer');
@define('MANAGE_IMAGES', 'Hantera bilder');
@define('NAME', 'Namn');
@define('EMAIL', 'E-post');
@define('HOMEPAGE', 'Hemsida');
@define('COMMENT', 'Kommentar');
@define('REMEMBER_INFO', 'Kom ihåg information? ');
@define('SUBMIT_COMMENT', 'Spara kommentar');
@define('NO_ENTRIES_TO_PRINT', 'Ingen artikel att skriva ut');
@define('COMMENTS', 'Kommentarer');
@define('ADD_COMMENT', 'Lägg till kommentar');
@define('NO_COMMENTS', 'Inga kommentarer');
@define('POSTED_BY', 'Skapad av');
@define('ON', 'den');
@define('A_NEW_COMMENT_BLAHBLAH', 'En ny kommentar har skrivits i din blogg "%s", till artikeln med namnet "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'En ny trackback har gjorts till din blogg-artikel med namnet "%s".');
@define('NO_CATEGORY', 'Ingen kategori');
@define('ENTRY_BODY', 'Innehåll artikel');
@define('EXTENDED_BODY', 'Utökat innehåll');
@define('CATEGORY', 'Kategori');
@define('EDIT', 'Redigera');
@define('NO_ENTRIES_BLAHBLAH', 'Inga artiklar hittade för sökningen %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Din sökning efter %s gav %s resultat:');
@define('IMAGE', 'Bild');
@define('ERROR_FILE_NOT_EXISTS', 'Fel: Det gamla filnamnet finns inte!');
@define('ERROR_FILE_EXISTS', 'Fel: Filnamnet finns redan, välj ett annat!');
@define('ERROR_SOMETHING', 'Fel: Någonting är fel.');
@define('ADDING_IMAGE', 'Lägger till bild...');
@define('THUMB_CREATED_DONE', 'Miniatyr skapad.<br/>Klar.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Fel: Filen finns redan i din dator!');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Ett okänt fel inträffade och filen laddades inte upp. Filstorleken är kanske större än vad som tillåts av din serverinstallation. Kolla med din tjänsteleverantör eller ändra i filen php.ini för att tillåta uppladdning av större filer.');
@define('GO', 'Kör!');
@define('NEWSIZE', 'Ny storlek: ');
@define('RESIZE_BLAHBLAH', '<b>Ändra storlek på %s</b>');
@define('ORIGINAL_SIZE', 'Ursprunglig storlek: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Här kan du anpassa bildstorleken. Om du vill ändra storlek proportionellt, ändra bara ett värde i något av de två fälten och tryck på TAB - Då ändras  automatiskt storleken automatiskt så att bildens proportioner bibehålls</p>');
@define('QUICKJUMP_CALENDAR', 'Snabbkalender');
@define('QUICKSEARCH', 'Snabbsök');
@define('SEARCH_FOR_ENTRY', 'Sök efter artikel');
@define('ARCHIVES', 'Arkiv');
@define('BROWSE_ARCHIVES', 'Bläddra i månadsarkivet');
@define('TOP_REFERRER', 'Vanligaste hänvisare');
@define('SHOWS_TOP_SITES', 'Vanligaste sajterna som länkat till din blogg');
@define('TOP_EXITS', 'Vanligaste utgångar');
@define('SHOWS_TOP_EXIT', 'Visar de vanligaste länkarna som använts ut från din blogg');
@define('SYNDICATION', 'Syndikering');
@define('SHOWS_RSS_BLAHBLAH', 'Visar RSS-syndikeringslänkar');
@define('ADVERTISES_BLAHBLAH', 'Visar ursprunget till din blogg');
@define('HTML_NUGGET', 'HTML-snutt');
@define('HOLDS_A_BLAHBLAH', 'Innehåller en liten snutt HTML i din sidonavigator');
@define('TITLE_FOR_NUGGET', 'Titel på HTML-snutten');
@define('THE_NUGGET', 'HTML-snutten!');
@define('SYNDICATE_THIS_BLOG', 'Syndikera denna blogg');
@define('YOU_CHOSE', 'Du valde %s');
@define('IMAGE_ROTATE_LEFT', 'Rotera bilden 90 grader motsols');
@define('IMAGE_ROTATE_RIGHT', 'Rotera bilden 90 grader medsols');
@define('IMAGE_SIZE', 'Bildstorlek');
@define('IMAGE_AS_A_LINK', 'Infoga bild');
@define('POWERED_BY', 'Baseras på');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Inga trackbacks');
@define('TOPICS_OF', 'Ämnen från');
@define('VIEW_FULL', 'Visa alla');
@define('VIEW_TOPICS', 'Visa ämnen');
@define('AT', 'kl');
@define('SET_AS_TEMPLATE', 'Använd som mall');
@define('IN', 'i');
@define('EXCERPT', 'Utdrag');
@define('TRACKED', 'Spårad');
@define('LINK_TO_ENTRY', 'Länk till artikel');
@define('LINK_TO_REMOTE_ENTRY', 'Länk till extern artikel');
@define('IP_ADDRESS', 'IP-adress');
@define('USER', 'Användare');
@define('THUMBNAIL_USING_OWN', 'Använder %s som miniatyr pga. dess storlek.');
@define('THUMBNAIL_FAILED_COPY', 'Ville använda %s som sin egen miniatyr men kunde inte kopiera den!');
@define('AUTHOR', 'Författare');
@define('LAST_UPDATED', 'Senast uppdaterad');
@define('TRACKBACK_SPECIFIC', 'Trackback URI för denna artikel');
@define('DIRECT_LINK', 'Direktlänk till denna artikel');
@define('COMMENT_ADDED', 'Din kommentar är tillagd. ');
@define('COMMENT_ADDED_CLICK', 'Klicka %shär för att komma tillbaka%s till kommentarerna, och %shär för att stänga%s detta fönster.');
@define('COMMENT_NOT_ADDED_CLICK', 'Klicka %shär för att komma tillbaka%s till kommentarerna, och %shär för att stänga%s detta fönster.');
@define('COMMENTS_DISABLE', 'Tillåt inte kommentarer för denna artikel');
@define('COMMENTS_ENABLE', 'Tillåt kommentarer för denna artikel');
@define('COMMENTS_CLOSED', 'Författaren tillåter inte kommentarer till denna artikel');
@define('EMPTY_COMMENT', 'Din kommentar innehåller ingenting, %sgå tillbaks%s och försök igen');
@define('ENTRIES_FOR', 'Artiklar från %s');
@define('DOCUMENT_NOT_FOUND', 'Dokumentet %s hittades inte.');
@define('USERNAME', 'Användarnamn');
@define('PASSWORD', 'Lösenord');
@define('AUTOMATIC_LOGIN', 'Spara information');
@define('SERENDIPITY_INSTALLATION', 'Installation av Serendipity');
@define('LEFT', 'Vänster');
@define('RIGHT', 'Höger');
@define('HIDDEN', 'Dold');
@define('REMOVE_TICKED_PLUGINS', 'Ta bort markerade insticksmoduler');
@define('SAVE_CHANGES_TO_LAYOUT', 'Spara layoutändringar');
@define('COMMENTS_FROM', 'Kommentarer från');
@define('ERROR', 'Fel');
@define('ENTRY_SAVED', 'Din artikel har sparats');
@define('DELETE_SURE', 'Vill du verkligen ta bort #%s permanent?');
@define('NOT_REALLY', 'Nej');
@define('DUMP_IT', 'Ja');
@define('RIP_ENTRY', 'Artikel #%s borttagen.');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategori #%s borttagen. Gamla artiklar flyttade till kategori #%s.');
@define('CATEGORY_DELETED', 'Kategori #%s borttagen.');
@define('INVALID_CATEGORY', 'Ingen kategori angiven för borttagning');
@define('CATEGORY_SAVED', 'Kategori sparad');
@define('SELECT_TEMPLATE', 'Välj vilken mall du vill använda för din blogg');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Artiklarna kunde inte läggas till!');
@define('MT_DATA_FILE', 'Movable Type datafil');
@define('FORCE', 'Tvinga');
@define('CREATE_AUTHOR', 'Skapa författare \'%s\'.');
@define('CREATE_CATEGORY', 'Skapa kategori \'%s\'.');
@define('MYSQL_REQUIRED', 'Du måste ha MySQL extension för att utföra denna operation.');
@define('COULDNT_CONNECT', 'Kunde inte ansluta till MySQL-databasen: %s.');
@define('COULDNT_SELECT_DB', 'Hittade inte databas: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Hittade inte användarinformation: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Hittade inte kategoriinformation: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Hittade inte artikelinformation: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Hittade inte kommentarinformation: %s.');
@define('YES', 'Ja');
@define('NO', 'Nej');
@define('USE_DEFAULT', 'Förvalt');
@define('CHECK_N_SAVE', 'Välj &amp; spara');
@define('DIRECTORY_WRITE_ERROR', 'Kan inte skriva till katalogen %s. Kontrollera rättigheter.');
@define('DIRECTORY_CREATE_ERROR', 'Katalogen %s finns inte och kunde inte skapas. Skapa katalogen manuellt');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; kör <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Kunde inte köra %s binärfil');
@define('FILE_WRITE_ERROR', 'Kan inte skriva till filen %s.');
@define('FILE_CREATE_YOURSELF', 'Skapa filen själv eller kontrollera rättigheter');
@define('COPY_CODE_BELOW', '<br />* Kopiera koden nedan och lägg den i %s i din %s mapp:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Ändra www till den användare apache kör som (t.ex. nobody eller www).');
@define('BROWSER_RELOAD', 'När du har gjort detta, välj "Uppdatera" eller motsvarande i din webbläsare.');
@define('DIAGNOSTIC_ERROR', 'Vi hittade några fel när vi körde diagnostik på din inmatade information:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity är inte installerad än. Var god <a href="%s">installera</a> nu.');
@define('INCLUDE_ERROR', 'Serendipity fel: kunde inte inkludera %s - avslutar.');
@define('DATABASE_ERROR', 'Serendipity fel: kunde inte ansluta till databas - avslutar.');
@define('CREATE_DATABASE', 'Skapar standardinställning för databas...');
@define('ATTEMPT_WRITE_FILE', 'Försöker skriva filen %s...');
@define('WRITTEN_N_SAVED', 'Konfiguration sparad');
@define('IMAGE_ALIGNMENT', 'Bildjustering');
@define('ENTER_NEW_NAME', 'Ange det nya namnet för: ');
@define('RESIZING', 'Ändrar storlek');
@define('RESIZE_DONE', 'Klar (böt storlek på %s bilder).');
@define('SYNCING', 'Synkroniserar databasen med bildkatalogen');
@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
@define('SYNC_DONE', 'Klar (synkroniserade %s bilder).');
@define('FILE_NOT_FOUND', 'Kunde inte hitta filen <b>%s</b>, kanske är den redan borttagen?');
@define('ABORT_NOW', 'Avbryt nu');
@define('REMOTE_FILE_NOT_FOUND', 'Kunde inte hitta filen på den externa servern, är du säker på att URL: <b>%s</b> är helt korrekt?');
@define('FILE_FETCHED', '%s hämtad som %s');
@define('FILE_UPLOADED', 'Filen %s uppladdad som %s');
@define('WORD_OR', 'Eller');
@define('SCALING_IMAGE', 'Skalar %s till %s x %s px');
@define('KEEP_PROPORTIONS', 'Behåll proportioner');
@define('REALLY_SCALE_IMAGE', 'Vill du verkligen ändra storlek? Detta kan inte ångras!');
@define('TOGGLE_ALL', 'Visa/dölj alla');
@define('TOGGLE_OPTION', 'Visa/dölj val');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Prenumerera på denna artikel');
@define('UNSUBSCRIBE_OK', "%s har nu avslutat prenumeration på denna artikel");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Ny kommentar till prenumererad artikel "%s"');
@define('SUBSCRIPTION_MAIL', "Hej %s,\n\nEn ny kommentar är gjord till artikeln du följer hos \"%s\", vid namn \"%s\"\nKommentarens skapare är: %s\n\nDu kan hitta artikeln här: %s\n\nDu kan avsluta prenumerationen genom att klicka på denna länk: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hej %s,\n\nEn ny trackback är gjord till artikeln du följer hos \"%s\", vid namn \"%s\"\nSkapare är: %s\n\nDu kan hitta artikeln här: %s\n\nDu kan avsluta prenumerationen genom att klicka på denna länk: %s\n");
@define('SIGNATURE', "\n-- \n%s bygger på Serendipty.\nDen bästa bloggen, och du kan också använda den.\nKolla <http://s9y.org> för att få veta hur.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 matning');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 matning');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 matning');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 kommentarer');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 matning');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Fält "managingEditor"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Fält "webMaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Bild för RSS matning');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Bildbredd');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Bildhöjd');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'E-post-adress till webmaster, om tillgänglig. (tom: dold) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mail-adress till ansvarig utgivare, om tillgänglig. (tom: dold) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL till en bild i GIF/JPEG/PNG format, om  tillgänglig. (tom: serendipity-logga)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'i pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'i pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Fält "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Antal minuter som din blogg maximalt bör cache-lagras av andra sajter/applikationer (tom: dold) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Fält "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Skall fälet "pubDate" ingå i en RSS-kanal för att visa datumet på senaste artikeln?');
@define('CONTENT', 'Innehåll');
@define('TYPE', 'Typ');
@define('DRAFT', 'Utkast');
@define('PUBLISH', 'Publicera');
@define('PREVIEW', 'Förhandsgranska');
@define('DATE', 'Datum');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Varning: Datumet du angav var ogiltigt. Det måste skrivas i formatet ÅÅÅÅ-MM-DD TT:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Visar listan med kategorier.');
@define('ALL_AUTHORS', 'Alla författare');
@define('CATEGORIES_TO_FETCH', 'Kategorier att hämta');
@define('CATEGORIES_TO_FETCH_DESC', 'Hämta kategorier från vilken författare?');
@define('PAGE_BROWSE_ENTRIES', 'Sida %s av %s, sammanlagt %s artiklar');
@define('PREVIOUS_PAGE', 'föregående sida');
@define('NEXT_PAGE', 'nästa sida');
@define('ALL_CATEGORIES', 'Alla kategorier');
@define('DO_MARKUP', 'Utför Markup Transformations');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Datumformatering');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formatet på artikelns verkliga datum, med hjälp PHPs strftime() variabler. (Ursprungsvärde: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Kunde inte öppna mallfil. Uppdatera Serendipity!');
@define('ADVANCED_OPTIONS', 'Utökade inställningar');
@define('EDIT_ENTRY', 'Redigera artikel');
@define('HTACCESS_ERROR', 'För att kontrollera din lokala webbserver-installation måste Serendipity kunna skriva till filen ".htaccess". Detta gick inte pga fel rättigheter. Justera rättigheterna så här: <br />&nbsp;&nbsp;%s<br />ladda om sidan.');
@define('SIDEBAR_PLUGINS', 'Sid-navigator Plugins');
@define('EVENT_PLUGINS', 'Händelse-plugin');
@define('SORT_ORDER', 'Sorteringordning');
@define('SORT_ORDER_NAME', 'Filnamn');
@define('SORT_ORDER_EXTENSION', 'Filändelse');
@define('SORT_ORDER_SIZE', 'Filstorlek');
@define('SORT_ORDER_WIDTH', 'Bildbredd');
@define('SORT_ORDER_HEIGHT', 'Bildhöjd');
@define('SORT_ORDER_DATE', 'Uppladdningsdatum');
@define('SORT_ORDER_ASC', 'Stigande');
@define('SORT_ORDER_DESC', 'Fallande');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Applicera textdekoration på %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Början av veckan');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Din nuvarande version av Serendipity är %s. Det verkar som om du försöker uppgradera till %s, så du behöver <a href="%s">klicka här</a> för att fortsätta uppgraderingsprocessen.');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Hej, och välkommen till Serendipitys uppgraderings-agent.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Jag är här för att hjälpa dig uppgradera din installation av Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Du ser det här meddelandet för att du just har installerat Serendipity %s men ännu inte uppgraderat din databas för att passa den här versionen');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Databasuppdateringar (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Jag har hittat följande .sql-filer som behöver köras innan du kan fortsätta använda Serendipity');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Versionsspecifika uppgifter');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Inga versionsspecifika uppgifter hittade');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Skall jag utföra ovanstående uppgifter?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nej, jag kör dem manuellt');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ja, tack');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Det ser ut som om du inte behöver köra några uppgraderingar');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity uppgraderad');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Du har struntat i uppgraderingsfasen av Serendipity, se till att databasen är korrekt installerad, och att schemalagda uppgifter körs');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Din Serendipity-installation är nu uppgraderad till version %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Du kan gå tillbaks till din blogg genom att klicka %shär%s');
@define('MANAGE_USERS', 'Hantera användare');
@define('CREATE_NEW_USER', 'Skapa ny användare');
@define('CREATE_NOT_AUTHORIZED', 'Du kan inte ändra användare med samma användarnivå som dig själv');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Du kan inte skapa användare med högre användarnivå än dig själv');
@define('CREATED_USER', 'En ny användare %s har skapats');
@define('MODIFIED_USER', 'Egenskaperna för användare %s har ändrats');
@define('USER_LEVEL', 'Användarnivå');
@define('DELETE_USER', 'Du är på väg att ta bort användare #%d %s. Är du helt säker? Det kommer att göra att inga artiklar skrivna av honom/henne kan visas.');
@define('DELETED_USER', 'Användare #%d %s borttagen.');
@define('LIMIT_TO_NUMBER', 'Hur många poster skall visas?');
@define('ENTRIES_PER_PAGE', 'artiklar per sida');
@define('XML_IMAGE_TO_DISPLAY', 'XML-knapp');
@define('XML_IMAGE_TO_DISPLAY_DESC','Länkar till XML-matningar kommer att visas med denna bild. Lämna tomt för standardbild, skriv \'none\' för att inaktivera.');

@define('DIRECTORIES_AVAILABLE', 'Klicka i listan över tillgängliga underkataloger för att skapa en ny katalog.');
@define('ALL_DIRECTORIES', 'Alla kataloger');
@define('MANAGE_DIRECTORIES', 'Alla kataloger');
@define('DIRECTORY_CREATED', 'Katalogen <strong>%s</strong> har skapats.');
@define('PARENT_DIRECTORY', 'Överliggande katalog');
@define('CONFIRM_DELETE_DIRECTORY', 'Är du säker på att du vill ta bort hela innehållet i katalogen %s?');
@define('ERROR_NO_DIRECTORY', 'Fel: Katalogen %s finns inte');
@define('CHECKING_DIRECTORY', 'Kollar filer i katalogen %s');
@define('DELETING_FILE', 'Tar bort filen %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Katalogen är inte tom och kan därför inte tas bort. Markera kryssrutan "force deletion" om du vill ta bort dessa kataloger. De filer som finns är:');
@define('DIRECTORY_DELETE_FAILED', 'Det gick inte att ta bort katalogen %s. Kolla rättigheter eller meddelandena här ovanför.');
@define('DIRECTORY_DELETE_SUCCESS', 'Katalogen %s borttagen.');
@define('SKIPPING_FILE_EXTENSION', 'Hoppar över fil: Saknas filändelse på %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Hoppar över fil: %s är inte läsbar.');
@define('FOUND_FILE', 'Hittad ny/ändrad fil: %s.');
@define('ALREADY_SUBCATEGORY', '%s är redan en underkatalog till %s.');
@define('PARENT_CATEGORY', 'Överordnad kategori');
@define('IN_REPLY_TO', 'Som svar till');
@define('TOP_LEVEL', 'Översta nivån');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s matning');
@define('PERMISSIONS', 'Rättigheter');
@define('INTEGRITY', 'Verifiera installationens integritet');
@define('CHECKSUMS_NOT_FOUND', 'Kunde inte jämföra kontrollsummor! (Ingen checksums.inc.php i huvudmappen)');
@define('CHECKSUMS_PASS', 'Alla nödvändiga filer verifierade..');
@define('CHECKSUM_FAILED', '%s korrupt eller ändrad: verifiering misslyckades');
@define('SETTINGS_SAVED_AT', 'De nya inställningarna har sparats på %s');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Databasinställningar');
@define('INSTALL_CAT_DB_DESC', 'Här fyller du i alla dina databasuppgifter. Serendipity behöver dessa för att fungera');
@define('INSTALL_DBTYPE', 'Databastyp');
@define('INSTALL_DBTYPE_DESC', 'Databastyp');
@define('INSTALL_DBHOST', 'Databasvärd');
@define('INSTALL_DBHOST_DESC', 'Värdnamnet för din databasserver');
@define('INSTALL_DBUSER', 'Databasanvändare');
@define('INSTALL_DBUSER_DESC', 'Användarnamnet som används för att ansluta till din databas');
@define('INSTALL_DBPASS', 'Databaslösenord');
@define('INSTALL_DBPASS_DESC', 'Lösenordet som hör till ovanstående användarnamn');
@define('INSTALL_DBNAME', 'Databasnamn');
@define('INSTALL_DBNAME_DESC', 'Namnet på din databas');
@define('INSTALL_DBPREFIX', 'Databasens tabellprefix');
@define('INSTALL_DBPREFIX_DESC', 'Prefixet för tabellnamnen, till exempel serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Sökvägar');
@define('INSTALL_CAT_PATHS_DESC', 'Olika sökvägar till nödvändiga mappar och filer. Glöm inte efterföljande snedstreck för kataloger!');
@define('INSTALL_FULLPATH', 'Fullständig sökväg');
@define('INSTALL_FULLPATH_DESC', 'Den absoluta (fullständiga) sökvägen till din Serendipity-installation');
@define('INSTALL_UPLOADPATH', 'Sökväg för uppladdning');
@define('INSTALL_UPLOADPATH_DESC', 'Allt uppladdat material hamnar här, relativt till \'Komplett sökväg\' - oftast \'uploads/\'');
@define('INSTALL_RELPATH', 'Relativ sökväg');
@define('INSTALL_RELPATH_DESC', 'Sökväg till Serendipity för din webbläsare. Oftast \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relativ mallsökväg');
@define('INSTALL_RELTEMPLPATH_DESC', 'Sökväg till mappen som innehåller dina mallar - Relativt till \'Relativ sökväg\'');
@define('INSTALL_RELUPLOADPATH', 'Relativ sökväg för uppladdat material');
@define('INSTALL_RELUPLOADPATH_DESC', 'Sökväg till ditt uppladdade material för din webbläsare - Relativt till \'Relativ sökväg\'');
@define('INSTALL_URL', 'URL till blogg');
@define('INSTALL_URL_DESC', 'Bas-URL till din Serendipity-installation');
@define('INSTALL_INDEXFILE', 'Index-fil');
@define('INSTALL_INDEXFILE_DESC', 'Namnet på din index-fil för Serendipity');

/* GENERAL SETTINGS */
@define('INSTALL_CAT_SETTINGS', 'Allmänna inställningar');
@define('INSTALL_CAT_SETTINGS_DESC', 'Anpassa hur Serendipity beter sig');
@define('INSTALL_USERNAME', 'Admin användarnamn');
@define('INSTALL_USERNAME_DESC', 'Änvändarnamn för administratörsinloggning');
@define('INSTALL_PASSWORD', 'Admin lösenord');
@define('INSTALL_PASSWORD_DESC', 'Lösenord för administratörsinloggning');
@define('INSTALL_EMAIL', 'Admin e-post');
@define('INSTALL_EMAIL_DESC', 'E-post till bloggadministratören');
@define('INSTALL_SENDMAIL', 'Skicka mail till admin?');
@define('INSTALL_SENDMAIL_DESC', 'Vill du få e-post när kommentarer skapas till dina artiklar?');
@define('INSTALL_SUBSCRIBE', 'Låt användare prenumerera på dina artiklar?');
@define('INSTALL_SUBSCRIBE_DESC', 'Tillåt användare att prenumera på en artikel och därigenom få ett mail när kommentarer görs till artikeln');
@define('INSTALL_BLOGNAME', 'Bloggens namn');
@define('INSTALL_BLOGNAME_DESC', 'Bloggens titel');
@define('INSTALL_BLOGDESC', 'Bloggens beskrivning');
@define('INSTALL_BLOGDESC_DESC', 'Din blogg-beskrivning');
@define('INSTALL_LANG', 'Språk');
@define('INSTALL_LANG_DESC', 'Ange språk för din blogg');

/* APPEARANCE AND OPTIONS */
@define('INSTALL_CAT_DISPLAY', 'Utseende och egenskaper');
@define('INSTALL_CAT_DISPLAY_DESC', 'Anpassa hur Serendipity ser ut');
@define('INSTALL_WYSIWYG', 'Använd WYSIWYG-editorn');
@define('INSTALL_WYSIWYG_DESC', 'Vill du använda WYSIWYG editorn? (Fungerar med IE5+, delvis i Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Tvinga till XHTML 1.1 standard');
@define('INSTALL_XHTML11_DESC', 'Vill du tvinga till XHTML 1.1 standard (kan orsaka problem för back-/frontend på äldre 4:e generations webbläsare)');
@define('INSTALL_POPUP', 'Tillåt användning av popup-fönster');
@define('INSTALL_POPUP_DESC', 'Vill du använda popup-fönster för kommentarer, trackbacks et al?');
@define('INSTALL_EMBED', 'Är Serendipity inbäddad?');
@define('INSTALL_EMBED_DESC', 'Om du vill bädda in Serendipity i en vanlig webbsida ska du välja detta för att enbart generera sidinnehållet. Du kan använda indexFile-alternativet för att använda en wrapper-klass där du skulle ha placerat det vanliga webbsidehuvudet. Läs README-filen för mer information!');
@define('INSTALL_TOP_AS_LINKS', 'Visa vanligaste utgångar/hänvisare som länkar?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Nej": Utgångar och hänvisare visas som vanlig text för att förhindra google-spam. "Ja": Utgångar och hänvisare visas som länkar. "Förvalt": Använd globala konfigureringsinställningar (rekommenderas).');
@define('INSTALL_BLOCKREF', 'Blockerade hänvisare');
@define('INSTALL_BLOCKREF_DESC', 'Finns det några speciella värdnamn som du inte vill ska visas i hänvisningslistan? En separat lista med värdnamn med \';\' och notera att värdnamnet blockeras med delsträngsmatchning!');
@define('INSTALL_REWRITE', 'URL Rewriting');
@define('INSTALL_REWRITE_DESC', 'Välj vilka regler du vill använda för att generera URLer. Genom att använda rewrite-regler kan du göra snygga URLer till din blogg och göra den lättare att indexera för spiders som google. Webbservern måste stödja antingen mod_rewrite eller "AllowOverride All" för din Serendipity-katalog. Den förvalda inställningen är auto-detected');

/* IMAGECONVERSION SETTINGS */
@define('INSTALL_CAT_IMAGECONV', 'Inställningar för bildkonvertering');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Ange allmän information om hur Serendipity skall hantera bilder');
@define('INSTALL_IMAGEMAGICK', 'Använd ImageMagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Har du ImageMagick installerat och vill du använda det för att ändra bildstorlekar?');
@define('INSTALL_IMAGEMAGICKPATH', 'Sökväg till konverteringsprogram');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Komplett sökväg & namn för ditt ImageMagick konverteringsprogram');
@define('INSTALL_THUMBSUFFIX', 'Miniatyrbildssuffix');
@define('INSTALL_THUMBSUFFIX_DESC', 'Miniatyrer kommer att döpas enligt följande format: original.[suffix].ext');
@define('INSTALL_THUMBWIDTH', 'Miniatyrbildsdimensioner');
@define('INSTALL_THUMBWIDTH_DESC', 'Statisk max-bredd för auto-genererade miniatyrbilder');
@define('INSTALL_THUMBDIM', 'Begränsad miniatyrbildsdimension');
@define('INSTALL_THUMBDIM_LARGEST', 'Störst');
@define('INSTALL_THUMBDIM_WIDTH', 'Bredd');
@define('INSTALL_THUMBDIM_HEIGHT', 'Höjd');
@define('INSTALL_THUMBDIM_DESC', 'Dimension att begränsa till miniatyrbildens maxstorlek. Ursprungsvärdet "' . 
    INSTALL_THUMBDIM_LARGEST .  '" begränsar båda dimensionerna, så att ingen av dem kan vara större än maxstorleken; "' . 
    INSTALL_THUMBDIM_WIDTH . '" och "' .  INSTALL_THUMBDIM_HEIGHT . 
    '" begränsa endast den valda dimensionen, så att den andra kan vara större än maxstorleken.');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Din personliga information');
@define('USERCONF_CAT_PERSONAL_DESC', 'Ändra din personliga information');
@define('USERCONF_USERNAME', 'Ditt användarnamn');
@define('USERCONF_USERNAME_DESC', 'Användarnamnet för att logga in till denna blogg');
@define('USERCONF_PASSWORD', 'Ditt lösenord');
@define('USERCONF_PASSWORD_DESC', 'Lösenordet du vill använda för att logga in till denna blogg');
@define('USERCONF_EMAIL', 'Din e-post adress');
@define('USERCONF_EMAIL_DESC', 'Din personliga e-post adress');
@define('USERCONF_SENDCOMMENTS', 'Skicka kommentar-meddelanden?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Vill du få e-post när kommentarer skapas till dina artiklar?');
@define('USERCONF_SENDTRACKBACKS', 'Skicka trackback-meddelanden');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Vill du få e-post när trackbacks skapas till dina artiklar?');
@define('USERCONF_ALLOWPUBLISH', 'Rättigheter: Publicera artiklar?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Har denna användare rätt att publicera artiklar?');
@define('SUCCESS', 'Framgång');
@define('POWERED_BY_SHOW_TEXT', 'Visa "Serendipity" som text');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Kommer att visa "Serendipity Weblog" som text');
@define('POWERED_BY_SHOW_IMAGE', 'Visa "Serendipity" med en logga');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Visar Serendipitys logga');
@define('PLUGIN_ITEM_DISPLAY', 'Var skall denna post visas?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Endast utvidgad artikel');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Endast översiktssida');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Alltid');
@define('RSS_IMPORT_CATEGORY', 'Använd denna kategori för icke matchande importerade artiklar');

@define('COMMENTS_WILL_BE_MODERATED', 'Kommentarer måste godkännas innan de visas.');
@define('YOU_HAVE_THESE_OPTIONS', 'Du har följande alternativ:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Varning: Den här kommentaren måste först godkännas');
@define('DELETE_COMMENT', 'Ta bort kommentar');
@define('APPROVE_COMMENT', 'Godkänn kommentar');
@define('REQUIRES_REVIEW', 'Kräver granskning');
@define('COMMENT_APPROVED', 'Komentaren #%s har blivit godkänd');
@define('COMMENT_DELETED', 'Kommentare #%s har blivit borttagen');
@define('COMMENTS_MODERATE', 'Kommentarer & trackbacks till denna artikel kommer att granskning innan de visas');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Varning: Denna trackback kräver godkännande innan den visas');
@define('DELETE_TRACKBACK', 'Ta bort trackback');
@define('APPROVE_TRACKBACK', 'Godkänn trackback');
@define('TRACKBACK_APPROVED', 'Trackback #%s har blivit godkänd');
@define('TRACKBACK_DELETED', 'Trackback #%s har tagits bort');
@define('VIEW', 'Visa');
@define('COMMENT_ALREADY_APPROVED', 'Kommentaren #%s verkar ha blivit godkänd redan');
@define('COMMENT_EDITED', 'Den valda kommentaren har redigerats');
@define('HIDE', 'Dölj');
@define('VIEW_EXTENDED_ENTRY', 'Fortsätt läsa "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Denna länk är inte avsedd att klickas på. Den innehåller en trackback-URI för denna artikel. Du kan använda denna URI för att skicka ping- & trackbacks från din egen blogg till denna artikel. För att kopiera länken, högerklicka och välj "Kopiera länk" i Internet Explorer eller "Kopiera länk ...." i Mozilla.');
@define('PLUGIN_SUPERUSER_HTTPS', 'Använd https vid inloggning');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Gör att inloggningslänken pekar på en https-URI. Din webbserver behöver ha stöd för https!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Gör externa länkar klickbara?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"Nej": Okontrollerade externa länkar (Topputgångar, topphänvisare, användarkommentarer) visas inte eller visas som vanlig text där så är lämpligt, för att förhindra google spam (rekommenderas). "Ja": Okontrollerade externa länkar visas som hyperlänkar. Detta kan åsidosättas inom sidomenykonfigrationen!');
@define('PAGE_BROWSE_COMMENTS', 'Sida %s av %s, sammanlagt %s kommentarer');
@define('FILTERS', 'Filter');
@define('FIND_ENTRIES', 'Sök artiklar');
@define('FIND_COMMENTS', 'Sök kommentarer');
@define('FIND_MEDIA', 'Sök media');
@define('FILTER_DIRECTORY', 'Katalog');
@define('SORT_BY', 'Sortera utefter');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Ingen trackback skickad: Kunde inte öppna anslutning till %s på port %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Mediebibliotek');
@define('ADD_MEDIA', 'Lägg till media');
@define('ENTER_MEDIA_URL', 'Ange en URL till en fil att hämta:');
@define('ENTER_MEDIA_UPLOAD', 'Välj en fil du vill ladda upp:');
@define('SAVE_FILE_AS', 'Spara filen som:');
@define('STORE_IN_DIRECTORY', 'Lagra i följande katalog: ');
@define('ADD_MEDIA_BLAHBLAH', '<b>Lägg till en fil till ditt mediebibliotek:</b><p>Här kan du ladda upp mediefiler, eller be mig att hämta dem från en plats på webben! Om du inte har någon lämplig bild, <a href="http://images.google.com" target="_blank">leta efter bilder på google</a> som passar dina tankar, resultaten är ofta användbara och roliga :) Men var försiktig, de flesta bilder är skyddade av upphovsrätten, så du måste fråga innan du använder dem.</p><p><b>Välj metod:</b></p><br/>');
@define('MEDIA_RENAME', 'Döp om denna fil');
@define('IMAGE_RESIZE', 'Ändra storlek denna bild');
@define('MEDIA_DELETE', 'Ta bort denna fil');
@define('FILES_PER_PAGE', 'Filer per sida');
@define('CLICK_FILE_TO_INSERT', 'Klicka på filen du vill infoga:');
@define('SELECT_FILE', 'Välj fil att infoga');
@define('MEDIA_FULLSIZE', 'Full storlek');
@define('CALENDAR_BOW_DESC', 'Veckodag som börjar vecka. Standardinställning är måndag');
@define('SUPERUSER', 'Administrera bloggen');
@define('ALLOWS_YOU_BLAHBLAH', 'Ger en länk i sid-navigatorn till blogg-administrationen');
@define('CALENDAR', 'Kalender');
@define('SUPERUSER_OPEN_ADMIN', 'Till administrationen');
@define('SUPERUSER_OPEN_LOGIN', 'Till inloggningssidan');
@define('INVERT_SELECTIONS', 'Invertera val');
@define('COMMENTS_DELETE_CONFIRM', 'Är du säker på att du vill ta bort de valda kommentarerna?');
@define('COMMENT_DELETE_CONFIRM', 'Är du säker på att du vill ta bort kommentaren #%d, skriven av %s?');
@define('DELETE_SELECTED_COMMENTS', 'Ta bort valda kommmentarer');
@define('VIEW_COMMENT', 'Visa kommentar');
@define('VIEW_ENTRY', 'Visa artikel');
@define('DELETE_FILE_FAIL' , 'Kan inte ta bort filen <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Ta bort miniatyren <b>%s</b>');
@define('DELETE_FILE', 'Ta bort filen <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Du håller p ta bort <b>%s</b><br />Om du använder den här filen i någon av dina artiklar får du länk-/bildfel<br />Vill du fortfarande ta bort den?<br /><br />');
@define('TRACKBACK_SENDING', 'Skickar trackback till URI %s...');
@define('TRACKBACK_SENT', 'Trackback fungerade');
@define('TRACKBACK_FAILED', 'Trackback misslyckades: %s');
@define('TRACKBACK_NOT_FOUND', 'Ingen trackback-URI hittad.');
@define('TRACKBACK_URI_MISMATCH', 'Den automatiskt funna trackback-URI:n matchar inte vår mål-URI.');
@define('TRACKBACK_CHECKING', 'Kollar <u>%s</u> möjliga trackbacks...');
@define('TRACKBACK_NO_DATA', 'Målet innehöll ingen data');
@define('TRACKBACK_SIZE', 'Mål-URI översker max-storlek på %s bytes.');
@define('COMMENTS_VIEWMODE_THREADED', 'Trådad');
@define('COMMENTS_VIEWMODE_LINEAR', 'Rak');
@define('DISPLAY_COMMENTS_AS', 'Visa kommentarer som');
@define('COMMENTS_FILTER_SHOW', 'Visa');
@define('COMMENTS_FILTER_ALL', 'Alla');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Bara godkända');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Väntar på godkännande');
@define('RSS_IMPORT_BODYONLY', 'Lägg all importerad text i "innehåll"-sektionen och splittra inte upp den i "utvidgad artikel"-sektionen.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Visa fullständiga artiklar med utvidgat innehåll i RSS-matningen');
@define('WEEK', 'Vecka');
@define('WEEKS', 'Veckor');
@define('MONTHS', 'Månader');
@define('DAYS', 'Dagar');
@define('ARCHIVE_FREQUENCY', 'Kalenderpost-frekvens');
@define('ARCHIVE_FREQUENCY_DESC', 'Kalenderintervall mellan varje post i listan');
@define('ARCHIVE_COUNT', 'Antalet poster i listan');
@define('ARCHIVE_COUNT_DESC', 'Totalt antal månader, veckor eller dagar att visa');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Här nedan är en lista med installerade insticksmoduler');
@define('SIDEBAR_PLUGIN', 'Insticksmodul för sid-navigatorn');
@define('EVENT_PLUGIN', 'Händelsebaserad insticksmodul');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klicka här för att installera en ny %s');
@define('VERSION', 'Version');
@define('INSTALL', 'Installera');
@define('ALREADY_INSTALLED', 'Redan installerad');
@define('SELECT_A_PLUGIN_TO_ADD', 'Välj den instickmodul som du vill installera');
@define('INSTALL_OFFSET', 'Kompensation för serverklocka');
@define('STICKY_POSTINGS', 'Spikade artiklar');
@define('INSTALL_FETCHLIMIT', 'Artiklar att visa på framsidan');
@define('INSTALL_FETCHLIMIT_DESC', 'Antal artiklar att visa per sida');
@define('IMPORT_ENTRIES', 'Importera data');
@define('EXPORT_ENTRIES', 'Exportera artiklar');
@define('IMPORT_WELCOME', 'Välkommen till Serendipitys importfunktion');
@define('IMPORT_WHAT_CAN', 'Här kan du importera artiklar från andra applikationer');
@define('IMPORT_SELECT', 'Ange applikationen du vill importera från');
@define('IMPORT_PLEASE_ENTER', 'Ange data enligt nedan');
@define('IMPORT_NOW', 'Importera nu!');
@define('IMPORT_STARTING', 'Startar importen...');
@define('IMPORT_FAILED', 'Import misslyckad');
@define('IMPORT_DONE', 'Importen gick bra');
@define('IMPORT_WEBLOG_APP', 'Webblogg-applikation');
@define('IMPORT_NOTES', 'Anteckning:');
@define('EXPORT_FEED', 'Exportera fullständig RSS-matning');
@define('STATUS', 'Status efter import');
@define('IMPORT_GENERIC_RSS', 'Generell RSS-import');
@define('ACTIVATE_AUTODISCOVERY', 'Skicka trackbacks till länkar funna i artikeln');
@define('WELCOME_TO_ADMIN', 'Välkommen till Serendipitys administrationssidor.');
@define('PLEASE_ENTER_CREDENTIALS', 'Ange dina inloggningsuppgifter nedan.');
@define('ADMIN_FOOTER_POWERED_BY', 'Driven av Serendipity %s och PHP %s');##
@define('INSTALL_USEGZIP', 'Använd gzip-komprimerade sidor');
@define('INSTALL_USEGZIP_DESC', 'För att snabba upp sidvisning kan sidorna komprimeras innan de skickas till besökaren (om hans/hennes webbläsare stödjer detta). Rekommenderas!');
@define('INSTALL_SHOWFUTURE', 'Visa framtida artiklar');
@define('INSTALL_SHOWFUTURE_DESC', 'Är alternativet valt kommer postdaterade artiklar att visas i din blogg. Standardinställningen är att dölja dessa artiklar och inte visa dem innan publiceringsdatumet inträtt.');
@define('INSTALL_DBPERSISTENT', 'Använd ihållande anslutning');
@define('INSTALL_DBPERSISTENT_DESC', 'Slå på användning av ihållande <a href="http://se.php.net/manual/sv/features.persistent-connections.php" target="_blank">databasanslutningar</a>. Rekommenderas normalt inte');
@define('NO_IMAGES_FOUND', 'Inga bilder hittades');
@define('PERSONAL_SETTINGS', 'Personliga inställningar');
@define('REFERER', 'Hänvisare');
@define('NOT_FOUND', 'Ej hittad');
@define('WRITABLE', 'Skrivbar');
@define('NOT_WRITABLE', 'Ej skrivbar');
@define('PROBLEM_DIAGNOSTIC', 'Du inte fortsätta med installationen tills felen ovan har åtgärdats');
@define('SELECT_INSTALLATION_TYPE', 'Välj vilken typ av installation du vill använda');
@define('WELCOME_TO_INSTALLATION', 'Välkommen till Serendipitys installation');
@define('FIRST_WE_TAKE_A_LOOK', 'Undersöker din nuvarande installation och försöker diagnostisera kompatibilitetsproblem');
@define('ERRORS_ARE_DISPLAYED_IN', 'Fel visas i %s, rekommendationer i %s och framgång i %s');
@define('RED', 'röd');
@define('YELLOW', 'gul');
@define('GREEN', 'grön');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s förinstallationsrapport');
@define('RECOMMENDED', 'Rekomenderad');
@define('ACTUAL', 'Verklig');
@define('PHPINI_CONFIGURATION', 'php.ini-konfiguration');
@define('PHP_INSTALLATION', 'PHP-installation');
@define('THEY_DO', 'det gör de');
@define('THEY_DONT', 'det gör de inte');
@define('SIMPLE_INSTALLATION', 'Enkel installation');
@define('EXPERT_INSTALLATION', 'Expertinstallation');
@define('COMPLETE_INSTALLATION', 'Komplett installation');
@define('WONT_INSTALL_DB_AGAIN', 'Kommer inte att installera databasen igen');
@define('CHECK_DATABASE_EXISTS', 'Kollar om databasen och tabellerna redan finns');
@define('CREATING_PRIMARY_AUTHOR', 'Skapar huvudförfattare \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Anger standardmall');
@define('INSTALLING_DEFAULT_PLUGINS', 'Installerar standardinsticksmoduler');
@define('SERENDIPITY_INSTALLED', 'Serendipity har installerats');
@define('VISIT_BLOG_HERE', 'Besök din nya blogg här');
@define('THANK_YOU_FOR_CHOOSING', 'Tack för att du valde Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'Ett fel upptäcktes i installationen');
@define('OPERATING_SYSTEM', 'Operativsystem');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('TEMPLATE_SET', '\'%s\' har valts som din aktiva mall');
@define('SEARCH_ERROR', 'Sökfunktionen fungerade inte som väntat. Meddelande till bloggens administratör: Kan bero på saknade indexnycklar i din databas. På MySQL-system måste databasens användare ha rätt att utföra följande kommando: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Felet som returnerades av databasen var: <pre>%s</pre>');
@define('EDIT_THIS_CAT', 'Redigerar "%s"');
@define('CATEGORY_REMAINING', 'Ta bort denna kategori och flytta dessa artiklar till denna kategori');
@define('CATEGORY_INDEX', 'Nedan är en lista med kategorier tillgängliga för dina artiklar');
@define('NO_CATEGORIES', 'Inga kategorier');
@define('RESET_DATE', 'Återställningsdatum');
@define('RESET_DATE_DESC', 'Klicka här för att återställa datumet till den nuvarande tiden');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Rättigheter kan ställas in genom att köra följande shellkommando: `<em>%s</em>` på katalogen som misslyckades, eller genom att ställa in detta med ett FTP-program');
@define('WARNING_TEMPLATE_DEPRECATED', 'Varning: Din nuvarande mall är föråldrad. Du bör updatera den om möjligt');
@define('ENTRY_PUBLISHED_FUTURE', 'Denna artikel är ännu ej publicerad.');
@define('ENTRIES_BY', 'Artiklar av %s');
@define('PREVIOUS', 'Föregående');
@define('NEXT', 'Nästa');
@define('APPROVE', 'Godkänn');
@define('DO_MARKUP_DESCRIPTION', 'Applicera förkortad textdekoration (smilies, snabbformatering med *, /, _, ...). Att avvaktivera detta kommer att bevara all HTML-kod i texten.');
@define('CATEGORY_ALREADY_EXIST', 'En kategori med namnet "%s" finns redan');
@define('ERROR_FILE_FORBIDDEN', 'Du har inte tillåtelse att ladda upp filer med körbart innehåll (t.ex. skript etc)');
@define('ADMIN', 'Administration');
@define('ADMIN_FRONTPAGE', 'Framsida');
@define('QUOTE', 'Citat');
@define('IFRAME_SAVE', 'Serendipity sparar din artikel, skapar trackbacks och utför eventualla XML-RPC-anrop. Det kan ta lite tid...');
@define('IFRAME_SAVE_DRAFT', 'Ett utkast till denna artikel har sparats');
@define('IFRAME_PREVIEW', 'Serendipity skapar förhandsgranskning av din artikel...');
@define('IFRAME_WARNING', 'Din webbläsare stöder inte iframes. Öppna filen serendipity_config.inc.php och sätt variabeln $serendipity[\'use_iframe\'] till FALSE.');
@define('NONE', 'ingen');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Normalinställningar för nya artiklar');
@define('UPGRADE', 'Uppgradera');
@define('UPGRADE_TO_VERSION', 'Uppgradera till version %s');
@define('DELETE_DIRECTORY', 'Ta bort katalog');
@define('DELETE_DIRECTORY_DESC', 'Du är på väg att ta bort en katalog som innehåller mediafiler vilka  ev. används i dina artiklar.');
@define('FORCE_DELETE', 'Ta bort ALLA filer i denna katalog, inklusive dem som inte är kända av Serendipity');
@define('CREATE_DIRECTORY', 'Skapa katalog');
@define('CREATE_NEW_DIRECTORY', 'Skapa ny katalog');
@define('CREATE_DIRECTORY_DESC', 'Här kan du skapa en ny katalog att lägga mediafiler i. Välj ett namn för din nya katalog och ange en eventuell katalog att placera den i.');
@define('BASE_DIRECTORY', 'Baskatalog');
@define('USERLEVEL_EDITOR_DESC', 'Standardredaktör');
@define('USERLEVEL_CHIEF_DESC', 'Chefredaktör');
@define('USERLEVEL_ADMIN_DESC', 'Administratör');
@define('USERCONF_USERLEVEL', 'Accessnivå');
@define('USERCONF_USERLEVEL_DESC', 'Denna nivå används för att bestämma vilken slags tillgång denna användare ska ha till bloggen');
@define('USER_SELF_INFO', 'Inloggad som %s (%s)');
@define('ADMIN_ENTRIES', 'Artiklar');
@define('RECHECK_INSTALLATION', 'Kolla installationen igen');
@define('IMAGICK_EXEC_ERROR', 'Kunde inte utföra: "%s", fel: %s, retur var: %d');
@define('INSTALL_OFFSET_DESC', 'Ange antal timmar mellan tiden på din webbserver (nuvarande: %clock%) och din önskade tidszon');
@define('UNMET_REQUIREMENTS', 'Kraven uppfylldes ej: %s');
@define('CHARSET', 'Teckenuppsättning');
@define('AUTOLANG', 'Använd besökarens webbläsarspråk som standardinställning');
@define('AUTOLANG_DESC', 'Om aktiverat, kommer besökarens språkinställning att avgöra standardinställning för språk på din artikel och för gränssnittsspråket.');
@define('INSTALL_AUTODETECT_URL', 'Känn igen HTTP-värd automatiskt');
@define('INSTALL_AUTODETECT_URL_DESC', 'Om satt till "true", kommer Serendipity se till att den HTTP-värd som användes av din besökare är din BaseURL-inställning. Om du aktiverar detta kommer du att kunna använda flera domännamn för din Serendipity Blogg och använda den domänen för uppföljande länkar som användaren använde för att få tillgång till din blogg.');
@define('CONVERT_HTMLENTITIES', 'Försök auto-konvertera HTML-entiteter?');
@define('EMPTY_SETTING', 'Du angav ett ogiltigt värde för "%s"!');
@define('USERCONF_REALNAME', 'Riktigt namm');
@define('USERCONF_REALNAME_DESC', 'Författarens hela namn. Detta namn ses av läsarna');
@define('HOTLINK_DONE', 'Filen länkad.<br />Klar.');
@define('ENTER_MEDIA_URL_METHOD', 'Hämtningsmetod:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Kommentar: Om du väljer att länka till en server bör du försäkra dig om att du har tillstånd att länka till den aktuella webbplatsen, eller att webbplatsen är din egen. Länkning låter dig använda bilder på andra webbplatser utan att behöva förvara dem lolalt.');
@define('MEDIA_HOTLINKED', 'länkad');
@define('FETCH_METHOD_IMAGE', 'Ladda ner bild till servern');
@define('FETCH_METHOD_HOTLINK', 'Länka till server');
@define('DELETE_HOTLINK_FILE', 'Ta bort den länkade filen <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Visa e-postadresser?');
@define('IMAGE_MORE_INPUT', 'Lägg till fler bilder');
@define('BACKEND_TITLE', 'Mer information på inställningsidan för insticksmoduler');
@define('BACKEND_TITLE_FOR_NUGGET', 'Här kan du definiera en valfri sträng som kommer att visas på inställningssidan för insticksmoduler tillsammans med beskrivningen av insticksmodulen HTML Nugget. Om du har flera HTML Nugget-insticksmoduler med en tom titel hjälper detta för att göra skilja dem från varandra.');
@define('CATEGORIES_ALLOW_SELECT', 'Tillåt besökare att visa flera kategorier samtidigt?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Om detta alternativ är valt kommer en kryssruta att visas bredvid varje kategori i denna sidomeny. Användare kan kryssa i dessa rutor och sedan se artiklar tillhörande detta urval.');
@define('PAGE_BROWSE_PLUGINS', 'Sida %s av %s, totalt %s insticksmoduler.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Definierar diverse URL-mönster för skapa permanenta länkar i din blogg. Det rekommenderas att du använder de förinställda värdena; om inte bör du försöka att använda %id%-värdet där det är möjligt för att förhindra att Serendipity frågar databasen efter mål-URLen.');
@define('INSTALL_PERMALINK', 'Artiklars permalink-URL-struktur');
@define('INSTALL_PERMALINK_DESC', 'Här kan du definiera URL-strukturen relativt till din bas-URL för att nå dina artiklar. Du kan använda variablerna %id%, %title%, %day%, %month%, %year% samt alla andra tecken.');
@define('INSTALL_PERMALINK_AUTHOR', 'Författares artiklars pemalink-URL-struktur');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Här kan du definiera URL-strukturen relativt till din bas-URL för att nå artiklar skrivna av vissa författare. Du kan använda variablerna %id%, %realname%, %username%, %email% samt alla andra tecken.');
@define('INSTALL_PERMALINK_CATEGORY', 'Kategoriers permalink-URL-struktur');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Här kan du definiera URL-strukturen relativt till din bas-URL för att nå artiklar i vissa kategorier. Du kan använda variablerna %id%, %name%, %parentname%, %description% samt alla andra tecken.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Kategoriers RSS-matningars permalink-URL-struktur');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Här kan du definiera URL-strukturen relativt till din bas-URL för att nå RSS-matningar från vissa kategorier. Du kan använda variablerna %id%, %name%, %description% samt alla andra tecken.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Sökväg till arkiv');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Sökväg till arkiv');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Sökväg till kategorier');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Sökväg till avbeställ kommentarer');
@define('INSTALL_PERMALINK_DELETEPATH', 'Sökväg till ta bort kommentarer');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Sökväg till godkänn kommentarer');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Sökväg till RSS-matningar');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Sökväg till enstaka insticksmodul');
@define('INSTALL_PERMALINK_ADMINPATH', 'Sökväg till administration');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Sökväg till sök');
@define('INSTALL_CAL', 'Kalendertyp');
@define('INSTALL_CAL_DESC', 'Välj önkskat kalenderformat');
@define('REPLY', 'Svara');
@define('USERCONF_GROUPS', 'Gruppmedlemskap');
@define('USERCONF_GROUPS_DESC', 'Denna användare är medlem av följande grupper. Flera medlemskap är möjliga.');
@define('MANAGE_GROUPS', 'Hantera grupper');
@define('DELETED_GROUP', 'Grupp #%d %s borttagen.');
@define('CREATED_GROUP', 'En ny grupp %s har skapats');
@define('MODIFIED_GROUP', 'Grupp %s egenskaper har ändrats');
@define('GROUP', 'Grupp');
@define('CREATE_NEW_GROUP', 'Skapa ny grupp');
@define('DELETE_GROUP', 'Du håller på att ta bort grupp #%d %s. Är du säker?');
@define('USERLEVEL_OBSOLETE', 'NOTERA: Användarnivåattributet används nu endast för bakåtkompatibilitet med insticksmoduler och reservauktorisering. Användarprivilegier hanteras nu genom gruppmedlemskap!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner-ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID för matningen som du vill publicera');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurnerbild');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Namn på bild att visa (eller lämna blankt för räknare), lokaliserad på feedburner.com, exempel: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurnertitel');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Titel (om någon) att visa tillsammans med bilden');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner bildtext');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Text (om någon) att visa när muspekaren hålls över bilden');
@define('SEARCH_TOO_SHORT', 'Ditt sökord måste vara längre än 3 bokstäver. Du kan försöka att lägga till * till kortare ord, till exempel s9y* för att lura sökfunktionen.');
@define('INSTALL_DBPORT', 'Databasport');
@define('INSTALL_DBPORT_DESC', 'Port som används för att ansluta till din databasserver');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Användargränssnitt: External Services');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Användargränssnitt: Funktioner');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Användargränssnitt: Fullprogram'); // AAAAAAAAAAHHH
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Användargränssnitt: Vyer');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Användargränssnitt: Artikelrelaterade');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Administrationsgränssnitt: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Administrationsgränssnitt: Usermanagement');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Administrationsgränssnitt: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Administrationsgränssnitt: Templates');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Administrationsgränssnitt: Features');
@define('PLUGIN_GROUP_IMAGES', 'Bilder');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Textdekoration');
@define('PLUGIN_GROUP_STATISTICS', 'Statistik');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Tillgå personliga inställningar');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Ändra användarnivå');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Ändra "Förbjud skapa artiklar"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Ändra rätt att publicera artiklar');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Tillgå systeminställningar');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Tillgå blogg-centrerade inställningar');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrativa artiklar');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrera andra användares artiklar');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importera artiklar');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrera kategorier');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrera andra användares kategorier');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Ta bort kategorier');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrera användare');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Ta bort användare');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Ändra användarnivå');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrera användare i din(a) grupp(er)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrera användare som inte är i din(a) grupp(er)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Skapa nya användare');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrera användargrupper');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrera insticksmoduler');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrera andra användares insticksmoduler');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrera mediafiler');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrera mediakataloger');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Lägg till nya mediafiler');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Ta bort mediafiler');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrera andra användares mediafiler');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Visa mediafiler');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Synkronisera miniatyrbilder');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrera kommentarer');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrera mallar');
@define('INSTALL_BLOG_EMAIL', 'Bloggens e-postadress');
@define('INSTALL_BLOG_EMAIL_DESC', 'Ställer in den e-postadress som används som avsändare i utgående meddelanden. Försäkra dig om att använda en adress som e-postservern på din värddator känner igen - många e-postservrar avfärdar meddelanden som har en okänd avsändaradress.');
@define('CATEGORIES_PARENT_BASE', 'Visa endast kategorier under...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Du kan välja en överordnad kategori så att endast dess underordnade kategorier visas.');
@define('CATEGORIES_HIDE_PARALLEL', 'Göm kategorier som inte är en del av kategoriträdet.');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Om du vill gömma kategorier som är dela av ett annat kategoriträd måste du välja detta. Denna funktion är mest användbar i samband med en multi-blogg som använder "Properties/Tempaltes of categories"-insticksmodulen.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Visa andra användares mediafiler');
@define('CHARSET_NATIVE', 'Inneboende');
@define('INSTALL_CHARSET', 'Tangentuppsättningsval');
@define('INSTALL_CHARSET_DESC', 'Här kan du välja UTF-8 eller inneboende (ISO, EUC, ...) tangentuppsättning. Vissa språk har endast UTF-8-översättningar och att välja tangentuppsättningen "Inneboende" har då ingen effekt. UTF-8 rekommenderas vid nyinstallation. Ändra inte denna inställning om du redan har skrivit artiklar med specialtecken - detta kan leda till korrupta tecken. Läs vänligen mer om detta på http://www.s9y.org/index.php?node=46 .');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Aktivera insticksmodulers API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Om detta akiveras kan insticksmoduler koppla in sig i kalendern för att visa sina egna händelser på ett framträdande sätt. Aktivera endast om du har installerat insticksmoduler som behöver detta, annars kommer det endast att medföra lägre prestanda.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'XML-RPC API gränssnittet till Serendipity inkluderas inte längre på grund av innevarande säkerhetsproblem med detta API samt att få använder det. Därför behöver du installera XML-RPC-insticksmoduken för att använda XML-RPC API:t. URL:en som används i din applikation kommer inte att ändras - så snart du har installerat insticksmodulen kommer du återigen att kunna använda API:t.');
@define('PERM_READ', 'Lästillstånd');
@define('PERM_WRITE', 'Skrivtillstånd');
@define('PERM_DENIED', 'Tillstånd nekas.');
@define('INSTALL_ACL', 'Använd lästillstånd för kategorier');
@define('INSTALL_ACL_DESC', 'Om detta aktiveras kommer användargruppstillstånden som du anger för kategorier att tillämpas när inloggade användare besöker din blogg. Om detta inaktiveras kommer lästillstånden för kategorier INTE att användas, men den positiva effekten är en liten uppsnabbning på din blogg. Alltså, om du inte behöver fleranvändarläsrättigheter för din blogg kan du inaktivera denna inställning.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Inställningssyntax fel för inställningen "%s". Innehåll av typen "%s" behövs.');
@define('USERCONF_CHECK_PASSWORD', 'Gammalt lösenord');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Om du ändrar lösenordet i fältet ovean måste du fylla i det nuvarande lösenordet i det här fältet.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Du har inte angett det gamla lösenordet på korrekt sätt och du har därför inte tillstånd att ändra lösenord. Dina inställningar sparades inte.');
@define('ERROR_XSRF', 'Din webbläsre skickade inte en giltig HTTP-hänvisarsträng. Detta kan ha orsakats av en felkonfigurerad webbläsare/proxy eller av en Cross Site Request Forgery (XSRF) riktad mot dig. Den efterfrågade handlingen kunde inte genomföras.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Här kan du definiera URL-strukturen relativt till din bas-URL för att nå RSS-matningar från vissa författare. Du kan använda variablerna %id%, %realname%, %username%, %email% och alla andra tecken.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Författares RSS-matningars permalink-URL-struktur');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Sökväg till författare');
@define('AUTHORS', 'Författare');
@define('AUTHORS_ALLOW_SELECT', 'Tillåt besökare att visa flera författare samtidigt?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Om detta alternativ är valt kommer en kryssruta att visas bredvid varje författare i denna sidomeny. Användare kan kryssa i dessa rutor och sedan se artiklar tillhörande detta urval.');
@define('AUTHOR_PLUGIN_DESC', 'Visar en lista med författare');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Aktivera Smarty-mallar?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'OM detta alternativ är valt kommer insticksmodulen att använda Smarty-mallafunktioner för att skriva ut kategorilistan. Om du väljer detta kan du ändra layouten genom mallfilen "plugin_categories.tpl". Att använda denna funtion påverkekar prestandan så låt den vara inaktiv om du inte behöver göra specialanpassningar.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Visa antalet artiklar i varje kategori?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Visa antalet artiklar bredvid författarens namn?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Om detta alternativ är valt kommer antalet artiklar av denna författare att visas bredvid författarens namn inom parantes.');
@define('CUSTOM_ADMIN_INTERFACE', 'Personligt administrationsgränssnitt tillgänligt');

@define('COMMENT_NOT_ADDED', 'Din kommentar kunde inte läggas till därför att antingen så är kommentarer inte tillåtna för denna artikel, det du skrev var inte tillåtet eller så filtrerade anti-spam filtret det. ');
@define('INSTALL_TRACKREF', 'Vill du slå på referrer tracking?');
@define('INSTALL_TRACKREF_DESC', 'Genom att slå på referrer tracking så ser du vilka webbplatser som refererar till dina artiklar. Det utnyttjas ofta av spammare så du kan välja att inte ha det påslaget.');
@define('CATEGORIES_HIDE_PARENT', 'Vill du gömma vald överordnad kategori?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Om du begränsar listningen av kategorier till en specifik kategori så kommer du att endast se den överordnade kategorin när de listas. Om du avaktiverar detta val så kommer inte den överordnade kategorin att visas.');
@define('WARNING_NO_GROUPS_SELECTED', 'OBS! Du valde inte något gruppmedlemskap. Det medför att du kommer att loggas ut från hanteringen av användargrupper. Ditt medlemskap har därför inte ändrats.');
@define('INSTALL_RSSFETCHLIMIT', 'Artiklar som visas i flöden');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Antal artiklar att visa på varje sida i RSS-flödet.');
@define('INSTAL_DB_UTF8', 'Aktivera Enable DB-teckenuppsättningskonvertering');
@define('INSTAL_DB_UTF8_DESC', 'Utfärdare MySQL-förfrågan "SET NAMES" för att indikera den för databasen nödvändiga teckenuppsättningen. Ändra denna inställning om du ser märkliga tecken i din blogg.');
@define('ONTHEFLYSYNCH', 'Aktivera mediasynkronisering');
@define('ONTHEFLYSYNCH_DESC', 'Om aktiv kommer Serendipity att jämföra mediadatabasen med filerna som lagras på din server och synkronisera databasen med mappinnehållet.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'Användarnamnet kan inte utelämnas.');
@define('FURTHER_LINKS', 'Fler länkar');
@define('FURTHER_LINKS_S9Y', 'Serendipitys hemsida');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipitys dokumentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Officiell blogg');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Forum');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Kommentar borttagen)');

@define('CURRENT_AUTHOR', 'Innevarande författare');

@define('WORD_NEW', 'Ny');
@define('SHOW_MEDIA_TOOLBAR', 'Visa verktygsrad i mediaväljarens popup-fönster?');
@define('MEDIA_KEYWORDS', 'Medianyckelord');
@define('MEDIA_KEYWORDS_DESC', 'Fyll i en lista med ord separerade av ";" som du vill använda som fördefinierade nyckelord för mediastycken.');
@define('MEDIA_EXIF', 'Importera EXIF/JPEG-bilddata');
@define('MEDIA_EXIF_DESC', 'Om aktiv kommer existerande EXIF/JPEG-metadata i bilder att läsas och lagras i databasen för visning i mediagalleriet.');
@define('MEDIA_PROP', 'Mediaegenskaper');


@define('GO_ADD_PROPERTIES', 'Mata in egenskaper');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Upphovsskydd');
@define('MEDIA_PROPERTY_COMMENT1', 'Kort kommentar');
@define('MEDIA_PROPERTY_COMMENT2', 'Lång kommentar');
@define('MEDIA_PROPERTY_TITLE', 'Titel');
@define('MEDIA_PROP_DESC', 'Fyll i en lista med egenskapsfält separerade av  ";" som du vill definiera för varje mediafil');
@define('MEDIA_PROP_MULTIDESC', '(Du kan lägga till ":MULTI" efter valfritt egenskapsfält för att indikera att detta kommer att innehålla en längre text snarare än enstaka tecken)');

@define('STYLE_OPTIONS_NONE', 'Denna stil har inga specifika inställningar. För att se hur din mall kan specifiera inställningar, läs "Technical Documentation" på www.s9y.org om "Configuration of Theme options".');
@define('STYLE_OPTIONS', 'Tema/stil-inställningar');

@define('PLUGIN_AVAILABLE_COUNT', 'Totalt: %d insticksmoduler.');

@define('SYNDICATION_RFC2616', 'Aktivera strikt RFC2616 RSS-flödesefterlevnad');
@define('SYNDICATION_RFC2616_DESC', 'Att INTE verkställa RFC2616 innebär att alla villkorliga GETs till Serendipity kommer att returnera artiklar som ändrats sedan den senaste förfrågan. Med den inställingen som "falsk" kommer dina besökare att få alla artiklar sedan deras senaste besök, vilket betraktas som en god sak. Dock kan vissa agenter såsom Planet att uppträda märkligt eftersom det strider mot RFC2616. Så om du sötter denna inställning som "true" kommer du att hålla dig till denna RFC, men läsare av dina RSS-flöden kan missa artiklar vid längre uppehåll. Antingen orsakar du problem för sammanställare som Planet eller för dina direkta läsare. Om du får klagomål från någon av dessa kan du ändra denna inställning. Se även: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
@define('MEDIA_PROPERTY_DATE', 'Tillhörande datum');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Speltid');
@define('FILENAME_REASSIGNED', 'Automatiskt tilldelat nytt filnamn: %s');
@define('MEDIA_UPLOAD_SIZE', 'Maximal uppladdningsstorlek för fil');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Mata in den maximala filstorleken för uppladdade filer i bytes. Denna inställning kan åsidosättas av serverinställningar i PHP.ini: upload_max_filesize, post_max_size, max_input_time kommer alla att ha företräde framför denna inställning. En tom sträng innebär att endast serverinställningarnas begränsning används.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Fel: Du kan inte ladda upp filer större än %s byte!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Maximal bredd på bilder som laddas upp');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Mata in den maximala bildbredden i pixlar för uppladdade bilder.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Maximal höjd på bilder som laddas upp');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Mata in den maximala bildhöjden i pixlar för uppladdade bilder.');
@define('MEDIA_UPLOAD_DIMERROR', 'Fel: Du kan inte ladda upp bildfiler större än %s x %s pixlar!');

@define('MEDIA_TARGET', 'Mål för denna länk');
@define('MEDIA_TARGET_JS', 'Popup-fönster (via JavaScript, adaptiv storlek)');
@define('MEDIA_ENTRY', 'Isolerad artikel');
@define('MEDIA_TARGET_BLANK', 'Popup-fönster (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Tillåt dynamisk bildskalning?');
@define('MEDIA_DYN_RESIZE_DESC', 'Om aktiv kan mediaväljaren returnera bilder i valfri efterfrågad storlek via en GET-variabel. Resultaten cache-lagras och kan därför skapa en stor filsamling om du använder detta intensivt.');

@define('MEDIA_DIRECTORY_MOVED', 'Mapp och filer flyttades utan problem till %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Mapp och filer kunde inte flyttas till %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'I andra databaser än MySQL är det inte möjligt att iterera genom varje artikel för att ersätta gammal mapps URL. Du kommer att behöva att redigera dina artiklar manuellt för att fixa ny URLer. Du kan fortfarande flytta din gamla mapp tillbaka till dess gamla plats om detta är för ansträngande.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Flyttade URLen för den flyttade mappen för %s artiklar.');
@define('PLUGIN_ACTIVE', 'Aktiv');
@define('PLUGIN_INACTIVE', 'Inaktiv');
@define('PREFERENCE_USE_JS', 'Aktivera avancerad JS-användning?');
@define('PREFERENCE_USE_JS_DESC', 'Om aktiv kommer avancerade JavaScript-sektioner att användas för större användbarhet, såsom att i sektionen för konfigurering av insticksmoduler kunna dra och släppa insticksmoduler för att ändra deras ordning.');

@define('PREFERENCE_USE_JS_WARNING', '(Denna sida använder avancerad JavaScript. Om du upplever funktionsproblem stäng av användningen av avancerad JS-användning i dina personliga inställningar eller stäng av din webbläsares JavaScript)');


@define('INSTALL_PERMALINK_COMMENTSPATH', 'Sökväg till kommentarer');
@define('PERM_SET_CHILD', 'Ange samma behörigheter på alla undermappar');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Förbjudna insticksmoduler');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Förbjudna händelser');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Aktivera ACL för insticksmoduler och användargrupper?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Om aktiv så kan du specifiera vilka användargrupper som får tillgång till olika insticksmoduler/händelser.');
@define('DELETE_SELECTED_ENTRIES', 'Ta bort valda artiklar');
@define('PLUGIN_AUTHORS_MINCOUNT', 'Visa enbart författare med minst X skrivna artiklar');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Lägg till denna länk som bokmärke och använd den sen på valfri sida som du vill blogga om för att snabbt komma åt din Serendipity-blogg.');
@define('IMPORT_WP_PAGES', 'Hämta även bilagor och statiska sidor som normala artiklar?');
@define('USERCONF_CREATE', 'Stäng av användare / förbjud aktivitet?');
@define('USERCONF_CREATE_DESC', 'Om vald har användaren inte några möjligheter att redigera eller skapa på bloggen längre. Vid inloggning i användargränssnittet kan användaren enbart se sina personliga inställningar samt logga ut.');
@define('CATEGORY_HIDE_SUB', 'Dölj inlägg gjorda i underkategorier?');
@define('CATEGORY_HIDE_SUB_DESC', 'Normalt sett när du bläddrar i en kategori kommer även artiklar från underkategorier att visas. Om denna inställning aktiveras kommer enbart artiklar i den valda kategorin att visas.');
@define('PINGBACK_SENDING', 'Skickar pingback till URI %s...');
@define('PINGBACK_SENT', 'Pingback lyckades');
@define('PINGBACK_FAILED', 'Pingback misslyckades: %s');
@define('PINGBACK_NOT_FOUND', 'Ingen pingback-URI hittades.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Dölj arkivlänken om inga artiklar skrevs i denna tidsrymd (kräver att artiklar räknas)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, kräver PHP5 och kan använda mycket minne');
@define('SET_TO_MODERATED', 'Moderera');
@define('COMMENT_MODERATED', 'Kommentar #%s har angetts som modererad');
@define('CENTER', 'centrera');
@define('FULL_COMMENT_TEXT', 'Ja, med komplett kommentarstext');

@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
@define('BADTOKEN', 'Invalid Moderation Link'); 

@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
@define('PLUGIN_DOCUMENTATION', 'Documentation');
@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD', '(If you enter an absolute URL with http://... here, this URL will be used as the redirection target in case you have enabled the "Force" option for FeedBurner. Note that this can also be a URL independent to FeedBurner. For new Google FeedBurner feeds, you need to enter http://feeds2.feedburner.com/yourfeedname here)');

@define('SYNDICATION_PLUGIN_FEEDBURNERID_FORWARD2', 'If you set this option to "Force" you can forward the RSS feed to any webservice, not only FeedBurner. Look at the option "Feedburner ID" below to enter an absolute URL)');
@define('COMMENTS_FILTER_NEED_CONFIRM', 'Pending user confirmation');
@define('NOT_WRITABLE_SPARTACUS', ' (Only required when you plan to use Spartacus plugin for remote plugin download)');
@define('MEDIA_ALT', 'ALT-Attribute (depiction or short description)');
@define('MEDIA_PROPERTY_ALT', 'Depiction (summary for ALT-Attribute)');

@define('MEDIA_TITLE', 'TITLE-Attribute (will be displayed on mouse over)');

@define('QUICKSEARCH_SORT', 'How should search-results be sorted?');

@define('QUICKSEARCH_SORT_RELEVANCE', 'Relevance');

